==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Okno dialogowe
Otwórz okno wyboru koloru</translatorcomment>
        <translation type="unfinished">Okno dialogowe</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Łuki i okręgi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">do odcinków (o stałej długości)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">na segmenty linii (kąt stały)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj elipsy
Elipsy</translatorcomment>
        <translation type="unfinished">Elipsy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">do polilinii z segmentami łuku</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">do polilinii z odcinków</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj krzywe składane
Rysuj krzywe składane (NURBS)</translatorcomment>
        <translation type="unfinished">Krzywe składane</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wymiary
Wymiarowanie
Pokaż menu &quot;Wymiarowanie&quot;</translatorcomment>
        <translation type="unfinished">Wymiary</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">w linii, brył i tekstów</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Rysuj kreskowanie i jednolite wypełnienia
Kreskowanie / całkowite Wypełnienia</translatorcomment>
        <translation type="unfinished">Włazy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">na linie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translatorcomment>--google--
Rozbij bloki oraz inne grupy obiektów
Zablokuj wszystkie bloki</translatorcomment>
        <translation type="unfinished">Bloki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">do podmiotów</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Modyfikuj
Zmień
Zmień atrybuty obiektu</translatorcomment>
        <translation type="unfinished">Zmień</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wybuch
&amp;Rozbij</translatorcomment>
        <translation type="unfinished">Wybuch</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Rozbij
&amp;Rozbij tekst na litery</translatorcomment>
        <translation type="unfinished">&amp;Rozbij</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Segmenty splajnu:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Segmenty elipsy (na pełnej elipsy):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Okno dialogowe
Otwórz okno wyboru koloru</translatorcomment>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Łuki i okręgi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na odcinki (o stałej długości)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na odcinki (o stałym kącie)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj elipsy
Elipsy</translatorcomment>
        <translation>Elipsy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na linie łamaną z segmentami łuków</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na linię łamaną z segmentami linii</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj krzywe składane
Rysuj krzywe składane (NURBS)</translatorcomment>
        <translation>Splajny</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wymiary
Wymiarowanie
Pokaż menu &quot;Wymiarowanie&quot;</translatorcomment>
        <translation>Wymiary</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na linie, bryły i teksty</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Rysuj kreskowanie i jednolite wypełnienia
Kreskowanie / całkowite Wypełnienia</translatorcomment>
        <translation>Kreskowanie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na linie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translatorcomment>--google--
Rozbij bloki oraz inne grupy obiektów
Zablokuj wszystkie bloki</translatorcomment>
        <translation>Bloki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>na obiekty</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Modyfikuj
Zmień
Zmień atrybuty obiektu</translatorcomment>
        <translation>Modyfikowanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wybuch
&amp;Rozbij</translatorcomment>
        <translation>Rozbij</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Rozbij
&amp;Rozbij tekst na litery</translatorcomment>
        <translation>&amp;Rozbij</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Rozbijanie znaków tekstu na linie łamane</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Liczba segmentów splajnu:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Liczba segmentów elipsy (dla pełnej elipsy):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Rozbijanie splajnów na linie łamane z segmentami linii</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Rozbijanie tekstów wielowierszowym na wiele bloków prostych tekstów</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Tolerancja aproksymacji splajnu:</translation>
    </message>
</context>
</TS>
